
=============
API Reference
=============

.. module:: caplena

This part of the documentation covers all the interfaces of our client library.

Client
------

.. autoclass:: Client
    :members:
    :inherited-members:


Controllers
-----------

.. autoclass:: caplena.endpoints.projects_endpoint.ProjectsController
    :members:


Filters
-------

.. autoclass:: caplena.filters.ProjectsFilter
    :members:

.. autoclass:: caplena.filters.RowsFilter
    :members:


Resources
---------

.. autoclass:: caplena.endpoints.projects_endpoint.ProjectDetail
    :members:

.. autoclass:: caplena.endpoints.projects_endpoint.ProjectList
    :members:

.. autoclass:: caplena.endpoints.projects_endpoint.RowsAppend
    :members:

.. autoclass:: caplena.endpoints.projects_endpoint.Row
    :members:
